unit egl;

interface

uses	Windows, Messages, SysUtils, Classes, gl, egltypes;

(* preliminary definitions for EGL 1.2/1.3 types *)
type
 EGLenum= EGLint;
type
 EGLClientBuffer= Pointer;

(* EGL Versioning *)
const EGL_VERSION_1_0	=		1;
const EGL_VERSION_1_1	=		1;
const EGL_VERSION_1_2	=		1;
const EGL_VERSION_1_3	=		1;

(* EGL Enumerants. Exceptional cases aside, most
 * enums are assigned unique values starting at $3000.
 *)

(* EGL aliases *)
const EGL_FALSE	=		0;
const EGL_TRUE	=		1;

(* Out-of-band attribute value *)
//const EGL_DONT_CARE	=		((EGLint)-1);

(* Errors / GetError result:= values *)
const EGL_SUCCESS	=		$3000;
const EGL_NOT_INITIALIZED	=	$3001;
const EGL_BAD_ACCESS	=		$3002;
const EGL_BAD_ALLOC	=		$3003;
const EGL_BAD_ATTRIBUTE	=	$3004;
const EGL_BAD_CONFIG	=		$3005;
const EGL_BAD_CONTEXT	=		$3006;
const EGL_BAD_CURRENT_SURFACE	=	$3007;
const EGL_BAD_DISPLAY	=		$3008;
const EGL_BAD_MATCH	=		$3009;
const EGL_BAD_NATIVE_PIXMAP	=	$300A;
const EGL_BAD_NATIVE_WINDOW	=	$300B;
const EGL_BAD_PARAMETER	=	$300C;
const EGL_BAD_SURFACE	=		$300D;
const EGL_CONTEXT_LOST	=	$300E;	(* EGL 1.1 - IMG_power_management *)

(* Reserved $300F-$301F for additional errors *)

(* Config attributes *)
const EGL_BUFFER_SIZE	=		$3020;
const EGL_ALPHA_SIZE	=		$3021;
const EGL_BLUE_SIZE	=		$3022;
const EGL_GREEN_SIZE	=		$3023;
const EGL_RED_SIZE	=		$3024;
const EGL_DEPTH_SIZE	=		$3025;
const EGL_STENCIL_SIZE	=	$3026;
const EGL_CONFIG_CAVEAT	=	$3027;
const EGL_CONFIG_ID	=		$3028;
const EGL_LEVEL	=		$3029;
const EGL_MAX_PBUFFER_HEIGHT	=	$302A;
const EGL_MAX_PBUFFER_PIXELS	=	$302B;
const EGL_MAX_PBUFFER_WIDTH	=	$302C;
const EGL_NATIVE_RENDERABLE	=	$302D;
const EGL_NATIVE_VISUAL_ID	=	$302E;
const EGL_NATIVE_VISUAL_TYPE	=	$302F;
const EGL_PRESERVED_RESOURCES	=	$3030;
const EGL_SAMPLES	=		$3031;
const EGL_SAMPLE_BUFFERS	=	$3032;
const EGL_SURFACE_TYPE	=	$3033;
const EGL_TRANSPARENT_TYPE	=	$3034;
const EGL_TRANSPARENT_BLUE_VALUE	=$3035;
const EGL_TRANSPARENT_GREEN_VALUE	=$3036;
const EGL_TRANSPARENT_RED_VALUE	=$3037;
const EGL_NONE	=		$3038;	(* Attrib list terminator *)
const EGL_BIND_TO_TEXTURE_RGB	=	$3039;
const EGL_BIND_TO_TEXTURE_RGBA	=$303A;
const EGL_MIN_SWAP_INTERVAL	=	$303B;
const EGL_MAX_SWAP_INTERVAL	=	$303C;
const EGL_LUMINANCE_SIZE	=	$303D;
const EGL_ALPHA_MASK_SIZE	=	$303E;
const EGL_COLOR_BUFFER_TYPE	=	$303F;
const EGL_RENDERABLE_TYPE	=	$3040;
const EGL_MATCH_NATIVE_PIXMAP	=	$3041;	(* Pseudo-attribute (not queryable) *)

(* Reserved $3041-$304F for additional config attributes *)

(* Config attribute values *)
const EGL_SLOW_CONFIG	=		$3050;	(* EGL_CONFIG_CAVEAT value *)
const EGL_NON_CONFORMANT_CONFIG	=$3051;	(* EGL_CONFIG_CAVEAT value *)
const EGL_TRANSPARENT_RGB	=	$3052;	(* EGL_TRANSPARENT_TYPE value *)
const EGL_RGB_BUFFER	=		$308E;	(* EGL_COLOR_BUFFER_TYPE value *)
const EGL_LUMINANCE_BUFFER	=	$308F;	(* EGL_COLOR_BUFFER_TYPE value *)

(* More config attribute values, for EGL_TEXTURE_FORMAT *)
const EGL_NO_TEXTURE	=		$305C;
const EGL_TEXTURE_RGB	=		$305D;
const EGL_TEXTURE_RGBA	=	$305E;
const EGL_TEXTURE_2D	=		$305F;

(* Config attribute mask bits *)
const EGL_PBUFFER_BIT	=		$01;	(* EGL_SURFACE_TYPE mask bits *)
const EGL_PIXMAP_BIT	=		$02;	(* EGL_SURFACE_TYPE mask bits *)
const EGL_WINDOW_BIT	=		$04;	(* EGL_SURFACE_TYPE mask bits *)
const EGL_OPENGL_ES_BIT	=	$01;	(* EGL_RENDERABLE_TYPE mask bits *)
const EGL_OPENVG_BIT	=		$02;	(* EGL_RENDERABLE_TYPE mask bits *)
const EGL_OPENGL_ES2_BIT	=	$04;	(* EGL_RENDERABLE_TYPE mask bits *)

(* QueryString targets *)
const EGL_VENDOR	=		$3053;
const EGL_VERSION	=		$3054;
const EGL_EXTENSIONS	=		$3055;
const EGL_CLIENT_APIS	=		$308D;

(* QuerySurface / CreatePbufferSurface targets *)
const EGL_HEIGHT	=		$3056;
const EGL_WIDTH	=		$3057;
const EGL_LARGEST_PBUFFER	=	$3058;
const EGL_TEXTURE_FORMAT	=	$3080;
const EGL_TEXTURE_TARGET	=	$3081;
const EGL_MIPMAP_TEXTURE	=	$3082;
const EGL_MIPMAP_LEVEL	=	$3083;
const EGL_RENDER_BUFFER	=	$3086;
const EGL_COLORSPACE	=		$3087;
const EGL_ALPHA_FORMAT	=	$3088;
const EGL_HORIZONTAL_RESOLUTION	=$3090;
const EGL_VERTICAL_RESOLUTION	=	$3091;
const EGL_PIXEL_ASPECT_RATIO	=	$3092;
const EGL_SWAP_BEHAVIOR	=	$3093;

(* EGL_RENDER_BUFFER values / BindTexImage / ReleaseTexImage buffer targets *)
const EGL_BACK_BUFFER	=		$3084;
const EGL_SINGLE_BUFFER	=	$3085;

(* OpenVG color spaces *)
const EGL_COLORSPACE_sRGB	=	$3089;	(* EGL_COLORSPACE value *)
const EGL_COLORSPACE_LINEAR	=	$308A;	(* EGL_COLORSPACE value *)

(* OpenVG alpha formats *)
const EGL_ALPHA_FORMAT_NONPRE	=	$308B;	(* EGL_ALPHA_FORMAT value *)
const EGL_ALPHA_FORMAT_PRE	=	$308C;	(* EGL_ALPHA_FORMAT value *)

(* Constant scale factor by which fractional display resolutions  and
 * aspect ratio are scaled when queried as integer values.
 *)
const EGL_DISPLAY_SCALING	=	10000;

(* Unknown display resolution/aspect ratio *)
//const EGL_UNKNOWN	=		((EGLint)-1);

(* Back buffer swap behaviors *)
const EGL_BUFFER_PRESERVED	=	$3094;	(* EGL_SWAP_BEHAVIOR value *)
const EGL_BUFFER_DESTROYED	=	$3095;	(* EGL_SWAP_BEHAVIOR value *)

(* CreatePbufferFromClientBuffer buffer types *)
const EGL_OPENVG_IMAGE	=	$3096;

(* QueryContext targets *)
const EGL_CONTEXT_CLIENT_TYPE	=	$3097;

(* CreateContext attributes *)
const EGL_CONTEXT_CLIENT_VERSION	=$3098;

(* BindAPI/QueryAPI targets *)
const EGL_OPENGL_ES_API	=	$30A0;
const EGL_OPENVG_API	=		$30A1;

(* GetCurrentSurface targets *)
const EGL_DRAW	=		$3059;
const EGL_READ	=		$305A;

(* WaitNative engines *)
const EGL_CORE_NATIVE_ENGINE	=	$305B;

(* EGL extensions must request enum blocks from the OpenGL ARB
 * Secretary, who maintains the EGL enumerant registry.
 *)

(* EGL Functions *)
function  eglGetError(): EGLint; stdcall; external 'libgles_cl.dll';

function  eglGetDisplay(display_id: NativeDisplayType ): EGLDisplay; stdcall; external 'libgles_cl.dll' name '_eglGetDisplay@4';
function  eglInitialize(dpy: EGLDisplay ; major: PEGLint ; minor: PEGLint ): EGLBoolean; stdcall; external 'libgles_cl.dll' name '_eglInitialize@12'; //*major *minor
function  eglTerminate(dpy: EGLDisplay ): EGLBoolean; stdcall; external 'libgles_cl.dll';

function   eglQueryString(dpy: EGLDisplay; name: EGLint ): Pchar; stdcall; external 'libgles_cl.dll'; //const PChar;

function  eglGetConfigs(dpy: EGLDisplay ; configs: PEGLConfig ; config_size: EGLint ; num_config: PEGLint ): EGLBoolean; stdcall; external 'libgles_cl.dll'; //*configs *num_config
function  eglChooseConfig(dpy: EGLDisplay ; const attrib_list: PEGLint ; configs: PEGLConfig ; config_size: EGLint ; num_config: PEGLint ): EGLBoolean; stdcall; external 'libgles_cl.dll' name '_eglChooseConfig@20';//*attrib_list *configs *num_config
function  eglGetConfigAttrib(dpy: EGLDisplay ; config: EGLConfig ; attribute: EGLint ; value: PEGLint ): EGLBoolean; stdcall; external 'libgles_cl.dll'; //*value

function  eglCreateWindowSurface(dpy: EGLDisplay ; config: EGLConfig ; win: NativeWindowType ; const attrib_list: PEGLint ): EGLSurface; stdcall; external 'libgles_cl.dll' name '_eglCreateWindowSurface@16'; //*attrib_list
function  eglCreatePbufferSurface(dpy: EGLDisplay ; config: EGLConfig ; const attrib_list: PEGLint ): EGLSurface; stdcall; external 'libgles_cl.dll'; //*attrib_list
function  eglCreatePixmapSurface(dpy: EGLDisplay ; config: EGLConfig ; pixmap: NativePixmapType ; const attrib_list: PEGLint ): EGLSurface; stdcall; external 'libgles_cl.dll'; //*attrib_list
function  eglDestroySurface(dpy: EGLDisplay ; surface: EGLSurface ): EGLSurface; stdcall; external 'libgles_cl.dll';
function  eglQuerySurface(dpy: EGLDisplay ; surface: EGLSurface ; attribute: EGLint ; value: PEGLint ): EGLSurface; stdcall; external 'libgles_cl.dll'; //*value

function   eglBindAPI(api: EGLenum ): EGLBoolean; stdcall; external 'libgles_cl.dll';
function   eglQueryAPI: EGLenum; stdcall; external 'libgles_cl.dll';

function   eglWaitClient: EGLBoolean; stdcall; external 'libgles_cl.dll';

function eglReleaseThread: EGLBoolean; stdcall; external 'libgles_cl.dll';

function   eglCreatePbufferFromClientBuffer(dpy: EGLDisplay ; buftype: EGLenum ; buffer: EGLClientBuffer ; config: EGLConfig ; const attrib_list: PEGLint ): EGLSurface; stdcall; external 'libgles_cl.dll'; //*attrib_list

function eglSurfaceAttrib(dpy: EGLDisplay ;surface:  EGLSurface ; attribute: EGLint ; value: EGLint ): EGLBoolean; stdcall; external 'libgles_cl.dll';
function eglBindTexImage(dpy: EGLDisplay ; surface: EGLSurface ; buffer: EGLint ): EGLBoolean; stdcall; external 'libgles_cl.dll';
function eglReleaseTexImage(dpy: EGLDisplay ; surface: EGLSurface ; buffer: EGLint): EGLBoolean; stdcall; external 'libgles_cl.dll';

function   eglSwapInterval(dpy: EGLDisplay ; interval: EGLint ): EGLBoolean; stdcall; external 'libgles_cl.dll';

function  eglCreateContext(dpy: EGLDisplay ; config: EGLConfig ; share_context: EGLContext ; const attrib_list: PEGLint ): EGLContext; stdcall; external 'libgles_cl.dll' name '_eglCreateContext@16'; //*attrib_list
function   eglDestroyContext(dpy: EGLDisplay ; ctx: EGLContext ): EGLBoolean; stdcall; external 'libgles_cl.dll';
function   eglMakeCurrent(dpy: EGLDisplay ; draw: EGLSurface ; read: EGLSurface ; ctx: EGLContext ): EGLBoolean; stdcall; external 'libgles_cl.dll' name '_eglMakeCurrent@16';

function eglGetCurrentContext: EGLContext; stdcall; external 'libgles_cl.dll';
function eglGetCurrentSurface(readdraw: EGLint ): EGLSurface; stdcall; external 'libgles_cl.dll';
function eglGetCurrentDisplay: EGLDisplay; stdcall; external 'libgles_cl.dll';
function eglQueryContext(dpy: EGLDisplay; ctx: EGLContext ; attribute: EGLint ; value: PEGLint ): EGLBoolean; stdcall; external 'libgles_cl.dll'; //*value

function   eglWaitGL: EGLBoolean; stdcall; external 'libgles_cl.dll';
function   eglWaitNative(engine: EGLint ): EGLBoolean; stdcall; external 'libgles_cl.dll';
function   eglSwapBuffers(dpy: EGLDisplay ; surface: EGLSurface ): EGLBoolean; stdcall; external 'libgles_cl.dll' name '_eglSwapBuffers@8';
function   eglCopyBuffers(dpy: EGLDisplay ; surface: EGLSurface ; target: NativePixmapType ): EGLBoolean; stdcall; external 'libgles_cl.dll';

procedure eglGetProcAddress(const procname:  PChar); stdcall; external 'libgles_cl.dll';

implementation
end.